@@ -35,7 +35,6 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
     CONF_SECTION = 'project_explorer'
 
-    open_terminal = Signal(str)
     open_interpreter = Signal(str)
     pythonpath_changed = Signal()
 
@@ -46,6 +45,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
     removed_tree = Signal(str)
     renamed = Signal(str, str)
     redirect_stdio = Signal(bool)
+    run = Signal(str)
 
     # Project handling
     sig_project_created = Signal(object, object, object)
@@ -383,9 +383,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
     def restart_consoles(self):
         """Restart consoles when closing, opening and switching projects"""
-        self.main.extconsole.restart()
-        if self.main.ipyconsole:
-            self.main.ipyconsole.restart()
+        self.main.ipyconsole.restart()
 
     def is_valid_project(self, path):
         """Check if a directory is a valid Spyder project"""
