@@ -22,6 +22,7 @@ import sys
 import mimetypes as mime
 
 # Third party imports
+from qtpy import API, is_pyqt46
 from qtpy.compat import getsavefilename, getexistingdirectory
 from qtpy.QtCore import (QDir, QFileInfo, QMimeData, QSize,
                          QSortFilterProxyModel, Qt, QTimer, QUrl,
@@ -32,14 +33,13 @@ from qtpy.QtWidgets import (QFileSystemModel, QHBoxLayout, QFileIconProvider,
                             QMessageBox, QToolButton, QTreeView, QVBoxLayout,
                             QWidget)
 # Local imports
-from spyder.config.base import _, get_home_dir
-from spyder.py3compat import (str_lower, to_binary_string,
-                              to_text_string)
+from spyder.config.base import _
+from spyder.py3compat import (getcwd, str_lower, to_binary_string,
+                              to_text_string, PY2)
 from spyder.utils import icon_manager as ima
 from spyder.utils import encoding, misc, programs, vcs
 from spyder.utils.qthelpers import (add_actions, create_action, file_uri,
                                     create_plugin_layout)
-from spyder.utils.misc import getcwd_or_home
 
 try:
     from nbconvert import PythonExporter as nbexporter
@@ -76,15 +76,10 @@ def fixpath(path):
 def create_script(fname):
     """Create a new Python script"""
     text = os.linesep.join(["# -*- coding: utf-8 -*-", "", ""])
-    try:
-        encoding.write(to_text_string(text), fname, 'utf-8')
-    except EnvironmentError as error:
-        QMessageBox.critical(_("Save Error"),
-                             _("<b>Unable to save file '%s'</b>"
-                               "<br><br>Error message:<br>%s"
-                               ) % (osp.basename(fname), str(error)))
+    encoding.write(to_text_string(text), fname, 'utf-8')
 
-def listdir(path, include=r'.', exclude=r'\.pyc$|^\.', show_all=False,
+
+def listdir(path, include='.', exclude=r'\.pyc$|^\.', show_all=False,
             folders_only=False):
     """List files and directories"""
     namelist = []
@@ -157,16 +152,7 @@ class IconProvider(QFileIconProvider):
                     icon = ima.icon(self.OFFICE_FILES[extension])
 
                 if mime_type is not None:
-                    try:
-                        # Fix for issue 5080.  Even though mimetypes.guess_type
-                        # documentation states that the return value will be
-                        # None or a tuple of the form type/subtype, in the
-                        # Windows registry, .sql has a mimetype of text\plain
-                        # instead of text/plain therefore mimetypes is
-                        # returning it incorrectly.
-                        file_type, bin_name = mime_type.split('/')
-                    except ValueError:
-                        file_type = 'text'
+                    file_type, bin_name = mime_type.split('/')
                     if file_type == 'text':
                         icon = ima.icon('TextFileIcon')
                     elif file_type == 'audio':
@@ -211,8 +197,9 @@ class DirView(QTreeView):
     def setup_view(self):
         """Setup view"""
         self.install_model()
-        self.fsmodel.directoryLoaded.connect(
-            lambda: self.resizeColumnToContents(0))
+        if not is_pyqt46:
+            self.fsmodel.directoryLoaded.connect(
+                                        lambda: self.resizeColumnToContents(0))
         self.setAnimated(False)
         self.setSortingEnabled(True)
         self.sortByColumn(0, Qt.AscendingOrder)
@@ -389,10 +376,16 @@ class DirView(QTreeView):
         dirname = fnames[0] if osp.isdir(fnames[0]) else osp.dirname(fnames[0])
         if len(fnames) == 1 and vcs.is_vcs_repository(dirname):
             # QAction.triggered works differently for PySide and PyQt
-            commit_slot = lambda fnames=[dirname]:\
-                                self.vcs_command(fnames, 'commit')
-            browse_slot = lambda fnames=[dirname]:\
-                                self.vcs_command(fnames, 'browse')
+            if not API == 'pyside':
+                commit_slot = lambda _checked, fnames=[dirname]:\
+                                    self.vcs_command(fnames, 'commit')
+                browse_slot = lambda _checked, fnames=[dirname]:\
+                                    self.vcs_command(fnames, 'browse')
+            else:
+                commit_slot = lambda fnames=[dirname]:\
+                                    self.vcs_command(fnames, 'commit')
+                browse_slot = lambda fnames=[dirname]:\
+                                    self.vcs_command(fnames, 'browse')
             vcs_ci = create_action(self, _("Commit"),
                                    icon=ima.icon('vcs_commit'),
                                    triggered=commit_slot)
@@ -474,13 +467,8 @@ class DirView(QTreeView):
                 
     def contextMenuEvent(self, event):
         """Override Qt method"""
-        # Needed to handle not initialized menu.
-        # See issue 6975
-        try:
-            self.update_menu()
-            self.menu.popup(event.globalPos())
-        except AttributeError:
-            pass
+        self.update_menu()
+        self.menu.popup(event.globalPos())
 
     def keyPressEvent(self, event):
         """Reimplement Qt method"""
@@ -670,10 +658,7 @@ class DirView(QTreeView):
                     return
             try:
                 misc.rename_file(fname, path)
-                if osp.isfile(fname):
-                    self.parent_widget.renamed.emit(fname, path)
-                else:
-                    self.parent_widget.renamed_tree.emit(fname, path)
+                self.parent_widget.renamed.emit(fname, path)
                 return path
             except EnvironmentError as error:
                 QMessageBox.critical(self, _("Rename"),
@@ -699,18 +684,14 @@ class DirView(QTreeView):
             self.rename_file(fname)
 
     @Slot()
-    def move(self, fnames=None, directory=None):
+    def move(self, fnames=None):
         """Move files/directories"""
         if fnames is None:
             fnames = self.get_selected_filenames()
         orig = fixpath(osp.dirname(fnames[0]))
         while True:
             self.parent_widget.redirect_stdio.emit(False)
-            if directory is None:
-                folder = getexistingdirectory(self, _("Select directory"),
-                                              orig)
-            else:
-                folder = directory
+            folder = getexistingdirectory(self, _("Select directory"), orig)
             self.parent_widget.redirect_stdio.emit(True)
             if folder:
                 folder = fixpath(folder)
@@ -886,7 +867,7 @@ class DirView(QTreeView):
                     self._to_be_loaded = []
                 self._to_be_loaded.append(path)
                 self.setExpanded(self.get_index(path), True)
-        if not self.__expanded_state:
+        if not self.__expanded_state and not is_pyqt46:
             self.fsmodel.directoryLoaded.disconnect(self.restore_directory_state)
                 
     def follow_directories_loaded(self, fname):
@@ -896,7 +877,8 @@ class DirView(QTreeView):
         path = osp.normpath(to_text_string(fname))
         if path in self._to_be_loaded:
             self._to_be_loaded.remove(path)
-        if self._to_be_loaded is not None and len(self._to_be_loaded) == 0:
+        if self._to_be_loaded is not None and len(self._to_be_loaded) == 0 \
+          and not is_pyqt46:
             self.fsmodel.directoryLoaded.disconnect(
                                         self.follow_directories_loaded)
             if self._scrollbar_positions is not None:
@@ -907,7 +889,7 @@ class DirView(QTreeView):
         """Restore all items expanded state"""
         if self.__expanded_state is not None:
             # In the old project explorer, the expanded state was a dictionnary:
-            if isinstance(self.__expanded_state, list):
+            if isinstance(self.__expanded_state, list) and not is_pyqt46:
                 self.fsmodel.directoryLoaded.connect(
                                                   self.restore_directory_state)
                 self.fsmodel.directoryLoaded.connect(
@@ -1085,7 +1067,7 @@ class ExplorerTreeWidget(DirView):
         """Refresh widget
         force=False: won't refresh widget if path has not changed"""
         if new_path is None:
-            new_path = getcwd_or_home()
+            new_path = getcwd()
         if force_current:
             index = self.set_current_folder(new_path)
             self.expand(index)
@@ -1106,7 +1088,7 @@ class ExplorerTreeWidget(DirView):
     @Slot()
     def go_to_parent_directory(self):
         """Go to parent directory"""
-        self.chdir(osp.abspath(osp.join(getcwd_or_home(), os.pardir)))
+        self.chdir( osp.abspath(osp.join(getcwd(), os.pardir)) )
 
     @Slot()
     def go_to_previous_directory(self):
@@ -1122,13 +1104,9 @@ class ExplorerTreeWidget(DirView):
         
     def update_history(self, directory):
         """Update browse history"""
-        try:
-            directory = osp.abspath(to_text_string(directory))
-            if directory in self.history:
-                self.histindex = self.history.index(directory)
-        except Exception:
-            user_directory = get_home_dir()
-            self.chdir(directory=user_directory, browsing_history=True)
+        directory = osp.abspath(to_text_string(directory))
+        if directory in self.history:
+            self.histindex = self.history.index(directory)
         
     def chdir(self, directory=None, browsing_history=False):
         """Set directory as working directory"""
@@ -1148,15 +1126,8 @@ class ExplorerTreeWidget(DirView):
                 self.history.append(directory)
             self.histindex = len(self.history)-1
         directory = to_text_string(directory)
-        try:
-            PermissionError
-            FileNotFoundError
-        except NameError:
+        if PY2:
             PermissionError = OSError
-            if os.name == 'nt':
-                FileNotFoundError = WindowsError
-            else:
-                FileNotFoundError = IOError
         try:
             os.chdir(directory)
             self.parent_widget.open_dir.emit(directory)
@@ -1165,9 +1136,6 @@ class ExplorerTreeWidget(DirView):
             QMessageBox.critical(self.parent_widget, "Error",
                                  _("You don't have the right permissions to "
                                    "open this directory"))
-        except FileNotFoundError:
-            # Handle renaming directories on the fly. See issue #5183
-            self.history.pop(self.histindex)
 
 
 class ExplorerWidget(QWidget):
@@ -1209,7 +1177,7 @@ class ExplorerWidget(QWidget):
 
         # Setup widgets
         self.treewidget.setup(name_filters=name_filters, show_all=show_all)
-        self.treewidget.chdir(getcwd_or_home())
+        self.treewidget.chdir(getcwd())
         self.treewidget.common_actions += [None, icontext_action]
 
         button_previous.setDefaultAction(previous_action)
