@@ -754,12 +754,8 @@ class SaveHistoryMixin(object):
         if self.history_filename not in self.HISTORY_FILENAMES:
             self.HISTORY_FILENAMES.append(self.history_filename)
             text = self.SEPARATOR + text
-        # Needed to prevent errors when writing history to disk
-        # See issue 6431
-        try:
-            encoding.write(text, self.history_filename, mode='ab')
-        except (IOError, OSError):
-            pass
+        
+        encoding.write(text, self.history_filename, mode='ab')
         if self.append_to_history is not None:
             self.append_to_history.emit(self.history_filename, text)
 
@@ -817,7 +813,3 @@ class BrowseHistoryMixin(object):
                     return entry[len(tocursor):], idx
             else:
                 return None, start_idx
-
-    def reset_search_pos(self):
-        """Reset the position from which to search the history"""
-        self.histidx = None
