@@ -45,7 +45,7 @@ def test_arrayeditor_format(qtbot):
     qtbot.keyClick(dlg.arraywidget.view, Qt.Key_Down, modifier=Qt.ShiftModifier)
     qtbot.keyClick(dlg.arraywidget.view, Qt.Key_Down, modifier=Qt.ShiftModifier)
     contents = dlg.arraywidget.view._sel_to_text(dlg.arraywidget.view.selectedIndexes())
-    assert contents == "1.000\n2.000\n"
+    assert contents == "1\n2\n"
     dlg.arraywidget.view.model().set_format("%.18e")
     assert dlg.arraywidget.view.model().get_format() == "%.18e"
     qtbot.keyClick(dlg.arraywidget.view, Qt.Key_Down, modifier=Qt.ShiftModifier)
@@ -120,6 +120,45 @@ def test_arrayeditor_with_3d_array(qtbot):
     assert_array_equal(arr, launch_arrayeditor(arr, "3D array"))
 
 
+def test_arrayeditor_edit_1d_array(qtbot):
+    exp_arr = np.array([1, 0, 2, 3, 4])
+    arr = np.arange(0, 5)
+    dlg = ArrayEditor()
+    assert dlg.setup_and_check(arr, '1D array', xlabels=None, ylabels=None)
+    dlg.show()
+    qtbot.waitForWindowShown(dlg)
+    view = dlg.arraywidget.view
+
+    qtbot.keyPress(view, Qt.Key_Down)
+    qtbot.keyPress(view, Qt.Key_Up)
+    qtbot.keyClicks(view, '1')
+    qtbot.keyPress(view, Qt.Key_Down)
+    qtbot.keyClicks(view, '0')
+    qtbot.keyPress(view, Qt.Key_Down)
+    qtbot.keyPress(view, Qt.Key_Return)
+    assert np.sum(exp_arr == dlg.get_value()) == 5
+
+
+def test_arrayeditor_edit_2d_array(qtbot):
+    arr = np.ones((3, 3))
+    diff_arr = arr.copy()
+    dlg = ArrayEditor()
+    assert dlg.setup_and_check(arr, '2D array', xlabels=None, ylabels=None)
+    dlg.show()
+    qtbot.waitForWindowShown(dlg)
+    view = dlg.arraywidget.view
+
+    qtbot.keyPress(view, Qt.Key_Down)
+    qtbot.keyPress(view, Qt.Key_Right)
+    qtbot.keyClicks(view, '3')
+    qtbot.keyPress(view, Qt.Key_Down)
+    qtbot.keyPress(view, Qt.Key_Right)
+    qtbot.keyClicks(view, '0')
+    qtbot.keyPress(view, Qt.Key_Left)
+    qtbot.keyPress(view, Qt.Key_Return)
+
+    assert np.sum(diff_arr != dlg.get_value()) == 2
+
+
 if __name__ == "__main__":
     pytest.main()
-
