@@ -12,6 +12,7 @@ Tests for texteditor.py
 import pytest
 
 # Local imports
+from spyder.py3compat import PY2
 from spyder.widgets.variableexplorer.texteditor import TextEditor
 
 @pytest.fixture
@@ -31,6 +32,16 @@ dedekdh elkd ezd ekjd lekdj elkdfjelfjk e"""
     dlg_text = texteditor.get_value()
     assert text == dlg_text
 
+def test_texteditor_setup_and_check():
+    if PY2:
+        import string
+        dig_its = string.digits;
+        translate_digits = string.maketrans(dig_its,len(dig_its)*' ')
+        editor = TextEditor(None)
+        assert not editor.setup_and_check(translate_digits)
+    else:
+        assert True
+
 
 if __name__ == "__main__":
     pytest.main()
